@@ -14,7 +14,7 @@ from jwt import DecodeError, ExpiredSignatureError
 
 from init_helpers.dict_to_dataclass import dict_to_dataclass
 
-from connector_library.auth_server_connector.auth_server_connector import AuthServerConnector, JWTPayload, TokenType
+from auth_server_connector.auth_server_connector import AuthServerConnector, JWTPayload, TokenType
 
 logger = logging.getLogger(__name__)
 
